# Experimental Flatpak for the DevToys application

This contains files to build a Flatpak of the [DevToys](https://devtoys.app) application.

## Initial Setup

In order to run the build, [Flatpak](https://flatpak.org/setup/) needs to be installed. 

After that, you can install the Flatpak Builder to build this application:

```sh
$ flatpak install org.flatpak.Builder
```

## Building the Application

Building the Application can be done like this:

```sh
$ flatpak run org.flatpak.Builder --force-clean --install-deps-from=flathub --install build app.devtoys.DevToys.yml
```

This command will pull all dependencies, build the Flatpak and install it to your system for testing.

## Updating the sources

As the Flatpak Builder runs the builds without a internet connection, a list of required Node.js and Nuget packages
needs to be provided, so they can be downloaded and cached by Flatpak Builder.\
These files are stored inside the `sources` folder.

In order to update these cache files, the following steps can be used.

### Prerequesites

The following commands expect a local copy of the [DevToys repository](https://github.com/DevToys-app/DevToys), as well as two
tools from the [Flatpak Builder Tools](https://github.com/flatpak/flatpak-builder-tools):

```sh
# Local copy of DevToys
$ git clone --branch v2.0.4.0 https://github.com/DevToys-app/DevToys.git

# Flatpak Builder Tools
$ git clone https://github.com/flatpak/flatpak-builder-tools.git
$ pipx install flatpak-builder-tools/node
```

### Update sources for Dotnet

```sh
python flatpak-builder-tools/dotnet/flatpak-dotnet-generator.py --dotnet 8 --freedesktop 23.08 sources/nuget-sources-build.json DevToys/src/Build.sln
python flatpak-builder-tools/dotnet/flatpak-dotnet-generator.py --dotnet 8 --freedesktop 23.08 sources/nuget-sources-linux.json DevToys/src/DevToys-Linux.sln
```

### Update sources for Node.js

```sh
ROOT="$PWD"

# Remove existing build files
cd DevToys
git clean -fx

# Create NPM Lockfile
cd src/app/dev/DevToys.Blazor
npm install

# Remove node_modules, so it doesn't interfere with flatpak-node-generator
rm -r node_modules

# Build the package list
cd "$ROOT"
cp DevToys/src/app/dev/DevToys.Blazor/package-lock.json sources/package-lock.json
flatpak-node-generator -o sources/node-sources.json npm DevToys/src/app/dev/DevToys.Blazor/package-lock.json
```
